@@ -20,7 +20,7 @@ from holmes.handlers.violation import (
     MostCommonViolationsHandler, ViolationsHandler, ViolationHandler, ViolationDomainsHandler
 )
 from holmes.handlers.review import (
-    ReviewHandler, LastReviewsHandler
+    ReviewHandler, LastReviewsHandler, ReviewsInLastHourHandler
 )
 from holmes.handlers.domains import (
     DomainsHandler, DomainDetailsHandler, DomainViolationsPerDayHandler,
@@ -33,7 +33,9 @@ from holmes.handlers.search import (
 from holmes.handlers.settings import (
     TaxHandler
 )
-from holmes.handlers.request import RequestDomainHandler, LastRequestsHandler
+from holmes.handlers.request import (
+    RequestDomainHandler, LastRequestsHandler, RequestsInLastDayHandler
+)
 from holmes.handlers.limiter import LimiterHandler
 
 from holmes.handlers.bus import EventBusHandler
@@ -80,6 +82,7 @@ class HolmesApiServer(Server):
         handlers = [
             (r'/most-common-violations/?', MostCommonViolationsHandler),
             (r'/last-reviews/?', LastReviewsHandler),
+            (r'/reviews-in-last-hour/?', ReviewsInLastHourHandler),
             (r'/workers/?', WorkersHandler),
             (r'/workers/info/?', WorkersInfoHandler),
             (r'/page/([a-z0-9-]*)/review/([a-z0-9-]*)/?', ReviewHandler),
@@ -105,6 +108,7 @@ class HolmesApiServer(Server):
             (r'/limiters/?', LimiterHandler),
             (r'/next-jobs/?', NextJobHandler),
             (r'/last-requests/?', LastRequestsHandler),
+            (r'/requests-in-last-day/?', RequestsInLastDayHandler),
             (r'/version/?', VersionHandler),
         ]
 
