@@ -10,7 +10,7 @@ class RequiredMetaTagsValidator(Validator):
     def get_violation_definitions(cls):
         return {
             'absent.meta.tags': {
-                'title': 'Required Meta Tags were not found.',
+                'title': 'Required Meta Tags were not found',
                 'description': lambda value: "Meta tags for %s were not found." % (', '.join(value)),
                 'category': 'HTTP'
             }
